import hashlib as _hashlib


def hash_text(text):
    sha256 = _hashlib.sha256()
    sha256.update(text.encode())
    hashed_text = sha256.hexdigest()
    return hashed_text


if __name__ == '__main__':
    print(hash_text('text'))





import requests as _requests
import json as _json
import functools as _functools
import pprint as _pprint
import traceback as _traceback
import base64 as _base64
from ..zip import compress_text as _compress_text
from ..zip import decompress_text as _decompress_text
import ast as _ast


def event2args(event):
    compressed_text = event['body']
    text = _decompress_text(compressed_text)
    return _ast.literal_eval(text)


def args2payload(*args):
    compressed_text = _compress_text(str(args))
    payload = compressed_text
    return payload


def trigger_via_apigateway(url, api_key=None, payload=None):
    method = "POST" if payload else "GET"
    kw = {}
    if api_key:
        kw['headers'] = {'x-api-key': api_key, }
    if payload:
        kw['data'] = _json.dumps(payload)
    return _requests.request(method, url, **kw)


def apigateway_decorator(lambda_handler):
    @_functools.wraps(lambda_handler)
    def lambda_handler_wrapper(event, context):
        try:
            body = _pprint.pformat(lambda_handler(event, context))
            statusCode = 200
        except Exception as e:
            statusCode = 500
            body = _traceback.format_exc()
            print(body)
        return {"statusCode": statusCode, "body": str(body)}
    return lambda_handler_wrapper


@apigateway_decorator
def lambda_handler(event, context):
    raise
    # return 'test'


if __name__ == '__main__':
    """
    returns "test!" if lambda_handler is like this.

    def test_trigger_via_apigateway():
        payload = {
            "api_key": "test!",
        }
        # not valid url and key, don't worry
        url = "https://k0ch7iuaj4.execute-api.us-west-2.amazonaws.com/default/asyc_superfast_receiver"
        api_key = "JJnYqNMTBU1LdIEjaSYL43G4OGfysL9B1In5oPoy"
        return trigger_via_apigateway(url, api_key, payload)
    import ast
    def lambda_handler(event, context):
        payload = ast.literal_eval(event['body'])
        return {
            "statusCode": 200,
            "body": payload['api_key']
        }
    """
    print(lambda_handler(None, None))



import requests as _requests
import os as _os
from .. import _set_env_value


def send_line(message, receiver_api_key=None):
    """
    How to get api key:
    https://qiita.com/iitenkida7/items/576a8226ba6584864d95
    return requests.post()
    """
    receiver_api_key = _set_env_value('line_api_key', receiver_api_key)
    url = "https://notify-api.line.me/api/notify"
    headers = {"Content-Type": "application/x-www-form-urlencoded",
               "Authorization": "Bearer " + receiver_api_key}
    data = {"message": message}
    response = _requests.post(url, headers=headers, data=data)
    response.raise_for_status()
    return response



import zlib as _zlib
import base64 as _base64


def decompress_text(compressed_text):
    return _zlib.decompress(_base64.b64decode(compressed_text)).decode()


def compress_text(text):
    compressed_text = _base64.b64encode(
        _zlib.compress(text.encode(), 9)).decode()
    return compressed_text


if __name__ == '__main__':
    longtext = 'zzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzzz'
    compressed_text = compress_text(longtext)
    text = decompress_text(compressed_text)
    print(len(longtext), longtext)
    print(len(compressed_text), compressed_text)
    print(len(text), text)
    assert text == longtext
